@@ -1,5 +1,6 @@
 from .base import Resource
 from ..constants.url import URL
+from ..constants.api_list import API_NAMES
 import datetime
 
 
@@ -27,21 +28,21 @@ class Payment(Resource):
         if "currency" not in data["amount"]:
             raise ValueError("\x1b[31m MISSING REQUEST PARAMS"
                              " \x1b[0m for currency")
-        return self.post_url(url, data, **kwargs)
+        return self.post_url(url, data, api_id=API_NAMES.CREATE_PAYMENT, **kwargs)
 
     def get_payment_details(self, id, **kwargs):
         url = "{}/{}".format(self.base_url, id)
         if id is None:
             raise ValueError("\x1b[31m MISSING REQUEST PARAMS"
                              " \x1b[0m for merchantPaymentId")
-        return self.fetch(None, url, **kwargs)
+        return self.fetch(None, url, None, api_id=API_NAMES.GET_PAYMENT, **kwargs)
 
     def cancel_payment(self, id, **kwargs):
         url = "{}/{}".format(self.base_url, id)
         if id is None:
             raise ValueError("\x1b[31m MISSING REQUEST PARAMS"
                              " \x1b[0m for merchantPaymentId")
-        return self.delete(None, url, **kwargs)
+        return self.delete(None, url, None, api_id=API_NAMES.CANCEL_PAYMENT, **kwargs)
 
     def refund_payment(self, data={}, **kwargs):
         url = "{}/".format('/v2/refunds')
@@ -62,14 +63,14 @@ class Payment(Resource):
         if "currency" not in data["amount"]:
             raise ValueError("\x1b[31m MISSING REQUEST PARAMS"
                              " \x1b[0m for currency")
-        return self.post_url(url, data, **kwargs)
+        return self.post_url(url, data, api_id=API_NAMES.REFUND_PAYMENT, **kwargs)
 
     def refund_details(self, id=None, **kwargs):
         if id is None:
             raise ValueError("\x1b[31m MISSING REQUEST PARAMS"
                              " \x1b[0m for merchantRefundId")
         url = "{}/{}".format('/v2/refunds', id)
-        return self.fetch(None, url, **kwargs)
+        return self.fetch(None, url, None, api_id=API_NAMES.GET_REFUND, **kwargs)
 
     def capture_payment(self, data=None, **kwargs):
         if data is None:
@@ -95,12 +96,12 @@ class Payment(Resource):
         if "currency" not in data["amount"]:
             raise ValueError("\x1b[31m MISSING REQUEST PARAMS "
                              "\x1b[0m for currency")
-        return self.post_url(url, data, **kwargs)
+        return self.post_url(url, data, api_id=API_NAMES.CAPTURE_PAYMENT, **kwargs)
 
     def create_continuous_payment(self, data=None, **kwargs):
         if data is None:
             data = {}
-        url = "{}/{}".format('v1/subscription', 'payments')
+        url = "{}/{}".format('/v1/subscription', 'payments')
         if "requestedAt" not in data:
             data['requestedAt'] = int(datetime.datetime.now().timestamp())
         if "merchantPaymentId" not in data:
@@ -118,7 +119,7 @@ class Payment(Resource):
         if "currency" not in data["amount"]:
             raise ValueError("\x1b[31m MISSING REQUEST PARAMS "
                              "\x1b[0m for currency")
-        return self.post_url(url, data, **kwargs)
+        return self.post_url(url, data,  api_id=API_NAMES.CREATE_CONTINUOUS_PAYMENT,  **kwargs)
 
     def revert_payment(self, data=None, **kwargs):
         if data is None:
@@ -132,4 +133,4 @@ class Payment(Resource):
         if "paymentId" not in data:
             raise ValueError("\x1b[31m MISSING REQUEST PARAMS"
                              " \x1b[0m for merchantPaymentId")
-        return self.post_url(url, data, **kwargs)
+        return self.post_url(url, data, api_id=API_NAMES.REVERT_AUTHORIZE, **kwargs)
